multidim.SimplexStratum — GDA Toolbox v1.0 Manual

# multidim.SimplexStratum

class `multidim.` `SimplexStratum`(cell_complex, dim)

  SimplexStratum is a thin class for calling `Simplex` objects of a certain dimension from a `SimplicialComplex`. It is an interface to the data in SimplicialComplex.stratum`[dim], which is a `pandas.DataFrame. Whenever possible, the `pandas.DataFrame` should be called directly, for speed.

#### Previous topic

multidim.SimplicialComplex.reset

#### Next topic

multidim.Simplex